@@ -178,7 +178,7 @@ public class TdTaskController {
 			taskCentralManager.reset();
 	
 
-		tdTaskService.getTdTasks(start, limit, true, new AsyncCallback<List<TdTaskModel>>() {
+		tdTaskService.getTdTasks(start, limit, resetTasksView, new AsyncCallback<List<TdTaskModel>>() {
 			
 			@Override
 			public void onSuccess(List<TdTaskModel> result) {
@@ -201,7 +201,7 @@ public class TdTaskController {
 			@Override
 			public void onFailure(Throwable caught) {
 				taskCentralManager.maskMainPanel(false);
-				MessageBox.alert("Error", "Sorry an error occurred on contacting the portal, try again later", null);
+				MessageBox.alert("Error", "Sorry an error occurred on contacting the service, try again later", null);
 				
 			}
 		});
@@ -260,7 +260,7 @@ public class TdTaskController {
 		win = new Window();
 		win.setHeading("Timeline Task Monitor");
 		int width = ConstantsTdTasks.MAINWIDTH+15;
-		int height = ConstantsTdTasks.MAINHEIGHT+15;
+		int height = ConstantsTdTasks.MAINHEIGHT+40;
 		win.setSize(width, height);
 	    win.add(mainPanel);
 	    win.setBottomComponent(mainPanel.getPagingToolbar());
